pub enum FoundNearbyNodeKind {
Unit,
Lit,
List,
}Expand description
How the nearby node relates to the one we were looking for
Variants
Unit
We were looking to go deeper, but found a unit in #[deftly]
Lit
We were looking to go deeper, but found a name = value in #[deftly]
List
We were looking for a leaf, but we found nested list in #[deftly]