pub struct FoundNearbyNode<'l> {
pub kind: FoundNearbyNodeKind,
pub path_span: Span,
pub ptree: &'l PreprocessedTree,
}Expand description
Information about a nearby meta node we found
“Nearby” means that the node we found is a prefix (in tree descent) of the one we were looking for, or vice versa.
Fields
kind: FoundNearbyNodeKindpath_span: SpanSpan of the identifier in the actual #[deftly] driver attribute
ptree: &'l PreprocessedTreeTrait Implementations