PreprocessedTree

Struct PreprocessedTree 

pub struct PreprocessedTree {
    pub path: Path,
    pub value: PreprocessedValue,
    pub used: Cell<UsageInfo<IsUsed>>,
}
An #[deftly()] attribute, or a sub-tree within one

Has interior mutability, for tracking whether the value is used. (So should ideally not be Clone, to help avoid aliasing bugs.)

Fields

path: Pathvalue: PreprocessedValueused: Cell<UsageInfo<IsUsed>>

Implementations

Source

impl PreprocessedTree

pub fn update_used(&self, ra: UsageInfo<IsUsed>)

Source

impl PreprocessedTree

fn encode_useds(list: &PreprocessedValueList) -> Option<Group>

Returns (....)

fn encode_used(&self, out: &mut TokenOutputTrimmer<'_, '_>)

Writes path?=(...) (or, rather, the parts of it that are needed)

Source

impl PreprocessedTree

fn check_used<'c>(&'c self, checker: &mut UsedChecker<'c, '_>)