pub struct PreprocessedTree {
pub path: Path,
pub value: PreprocessedValue,
pub used: Cell<UsageInfo<IsUsed>>,
}Expand description
An #[deftly()] attribute, or a sub-tree within one
Has interior mutability, for tracking whether the value is used. (So should ideally not be Clone, to help avoid aliasing bugs.)
Fields
path: Pathvalue: PreprocessedValueused: Cell<UsageInfo<IsUsed>>Implementations
Sourceimpl PreprocessedTree
impl PreprocessedTree
pub fn update_used(&self, ra: UsageInfo<IsUsed>)
Sourceimpl PreprocessedTree
impl PreprocessedTree
Sourcefn encode_useds(list: &PreprocessedValueList) -> Option<Group>
fn encode_useds(list: &PreprocessedValueList) -> Option<Group>
Returns (....)
Sourcefn encode_used(&self, out: &mut TokenOutputTrimmer<'_, '_>)
fn encode_used(&self, out: &mut TokenOutputTrimmer<'_, '_>)
Writes path?=(...) (or, rather, the parts of it that are needed)
Sourceimpl PreprocessedTree
impl PreprocessedTree
fn check_used<'c>(&'c self, checker: &mut UsedChecker<'c, '_>)